@@ -13,7 +13,7 @@ use Term::Choose           qw( choose );
 use URI                    qw();
 use URI::Escape            qw( uri_unescape );
 
-use App::YTDL::Data          qw( get_yt_download_info_as_h_ref get_download_info_as_json );
+use App::YTDL::Get_Data      qw( get_yt_download_info_as_h_ref get_download_info_as_json );
 use App::YTDL::Data_Extract  qw( add_entry_to_info_hash json_to_hash );
 use App::YTDL::Options       qw( sort_order_list );
 use App::YTDL::Choose_Videos qw( choose_videos );
@@ -30,22 +30,25 @@ sub from_arguments_to_choices {
         if ( my $channel_id = _user_id( $opt, $id ) ) {
             my $tmp = _id_to_tmp_info_hash( $opt, 'CL', $channel_id );
             my $ex = 'youtube';
-            choose_videos( $opt, $info, $tmp, $ex );
+            my ( $vi ) = keys %{$tmp->{$ex}};
+            my $prompt = $tmp->{$ex}{$vi}{uploader};
+            choose_videos( $opt, $info, $tmp, $ex, $prompt );
         }
         elsif ( my $playlist_id = _playlist_id( $opt, $id ) ) {
             my $tmp = _id_to_tmp_info_hash( $opt, 'PL', $playlist_id );
             my $ex = 'youtube';
-            choose_videos( $opt, $info, $tmp, $ex );
+            my $prompt = $playlist_id;
+            choose_videos( $opt, $info, $tmp, $ex, $prompt );
         }
         elsif ( my $more_ids = _more_ids( $opt, $id ) ) {
             my $tmp = _more_url_to_tmp_info_hash( $opt, $more_ids );
              my $ex = 'youtube';
-            choose_videos( $opt, $info, $tmp, $ex );
+             my $prompt = $more_ids;
+            choose_videos( $opt, $info, $tmp, $ex, $prompt );
         }
         elsif ( my $video_id = _video_id( $opt, $id )  ) {
             my $ex = 'youtube';
-            $info->{$ex}{$video_id}{extractor}     = 'youtube';
-            #$info->{$ex}{$video_id}{extractor_key} = 'Youtube';
+            $info->{$ex}{$video_id}{extractor} = 'youtube';
         }
         else {
             my $tmp = _non_yt_id_to_tmp_info_hash( $opt, $id );
@@ -56,7 +59,8 @@ sub from_arguments_to_choices {
                 $info->{$ex}{$video_id} = $tmp->{$ex}{$video_id};
             }
             else {
-                choose_videos( $opt, $info, $tmp, $ex );
+                my $prompt = $id;
+                choose_videos( $opt, $info, $tmp, $ex, $prompt );
             }
         }
     }
