@@ -109,10 +109,9 @@ sub _prepare_info_hash {
     $info->{$ex}{$video_id}{duration}        ||= '-:--:--';
     $info->{$ex}{$video_id}{upload_date}     ||= '0000-00-00';
     $info->{$ex}{$video_id}{upload_datetime} ||= '0000-00-00T00:00:00';
-    $info->{$ex}{$video_id}{upload_id}   //= '';
     $info->{$ex}{$video_id}{playlist_id} //= '';
-    $info->{$ex}{$video_id}{uploader}    //= $info->{$ex}{$video_id}{uploader_id} // '';
-    #$info->{$ex}{$video_id}{extractor_key} //= $info->{$ex}{$video_id}{extractor} // '';
+    $info->{$ex}{$video_id}{uploader_id} //= $info->{$ex}{$video_id}{uploader} // '';
+    $info->{$ex}{$video_id}{uploader}    //= $info->{$ex}{$video_id}{uploader_id};
     if ( $info->{$ex}{$video_id}{published} && $info->{$ex}{$video_id}{published} =~ /^(\d\d\d\d-\d\d-\d\d)T(\d\d:\d\d:\d\d)/ ) {
         $info->{$ex}{$video_id}{upload_date} = $1;
         $info->{$ex}{$video_id}{upload_datetime} = $1 . 'T' . $2;
