@@ -29,12 +29,13 @@ sub search_and_merge {
     if ( ! merge_requirements_ok( $opt ) ) {
         return;
     }
-    for my $ex ( keys %$info ) {
-        for my $video_id ( keys %{$info->{$ex}} ) {
+    my @merged;
+    EXTRACTOR: for my $ex ( keys %$info ) {
+        VIDEO_ID: for my $video_id ( keys %{$info->{$ex}} ) {
             if ( keys %{$info->{$ex}{$video_id}{file_name}} == 2 ) {
+                my ( $video, $audio );
+                my $height = '';
                 try {
-                    my ( $video, $audio );
-                    my $height = '';
                     for my $fmt ( keys %{$info->{$ex}{$video_id}{file_name}} ) {
                         my $file = $info->{$ex}{$video_id}{file_name}{$fmt};
                         my $stream_info = _get_stream_info( $opt, $file );
@@ -48,24 +49,35 @@ sub search_and_merge {
                             }
                         }
                     }
-                    if ( ! $audio ) {
-                        die "No file with audio-only stream!";
-                    }
-                    if ( ! $video ) {
-                        die "No file with video stream!";
-                    }
-                    my $video_dir = $info->{$ex}{$video_id}{video_dir};
-                    my $file_name = get_filename( $opt, $info->{$ex}{$video_id}{title}, $opt->{merge_ext}, $height );
-                    my $out = catfile $video_dir, $file_name;
-                    if ( -f $out && ! $opt->{merge_overwrite} ) {
-                        my $overwrite_ok = choose(
-                            [ 'NO merge', 'Merge and overwrite' ],
-                            { prompt => $out . ' already exists:', index => 1 }
-                        );
-                        return if ! $overwrite_ok;
+                }
+                catch {
+                    say "$video_id - Merge: $_";
+                    push @{$opt->{error_merge}}, $video_id;
+                    next VIDEO_ID
+                };
+                if ( ! $audio ) { #####
+                    say "$video_id: No file with audio-only stream!";
+                    next VIDEO_ID;
+                }
+                if ( ! $video ) {
+                    say "$video_id: No file with video stream!";
+                    next VIDEO_ID;
+                }
+                my $video_dir = $info->{$ex}{$video_id}{video_dir};
+                my $file_name = get_filename( $opt, $info->{$ex}{$video_id}{title}, $opt->{merge_ext}, $height );
+                my $out = catfile $video_dir, $file_name;
+                if ( -f $out && ! $opt->{merge_overwrite} ) {
+                    my $overwrite_ok = choose(
+                        [ 'NO merge', 'Merge and overwrite' ],
+                        { prompt => $out . ' already exists:', index => 1 }
+                    );
+                    if ( ! $overwrite_ok ) {
+                        next VIDEO_ID;
                     }
+                }
+                try {
                     _merge_video_with_audio( $opt, $video, $audio, $out );
-                    say "Merged: $out";
+                    push @merged, $out;
                     if ( $opt->{merged_in_files} == 1 ) {
                         my $dir_orig_files = catdir $video_dir, $opt->{dir_stream_files};
                         if ( ! -d $dir_orig_files ) {
@@ -85,10 +97,15 @@ sub search_and_merge {
                 catch {
                     say "$video_id - Merge: $_";
                     push @{$opt->{error_merge}}, $video_id;
+                    next VIDEO_ID;
                 };
             }
         }
     }
+    say 'Merged:';
+    for my $merged_file ( @merged ) {
+        say ' ' .  $merged_file;
+    }
 }
 
 
