@@ -16,7 +16,6 @@ use Pod::Usage            qw( pod2usage );
 
 use File::Which            qw( which );
 use IPC::System::Simple    qw( capture );
-use List::MoreUtils        qw( first_index );
 use Term::Choose           qw( choose );
 use Term::Choose::Util     qw( print_hash choose_a_dir choose_a_number insert_sep );
 use Term::ReadLine::Simple qw();
@@ -91,7 +90,7 @@ sub _menus {
             [ 'group_download',  "- Download"   ],
             [ 'group_merge',     "- Merge"      ],
             [ 'group_history',   "- History"    ],
-            [ 'group_list_menu', "- List menu"  ],
+            [ 'group_list_menu', "- Video list menu" ],
             [ 'group_output',    "- Appearance" ],
             [ 'list_extractors', "  Extractors" ],
         ],
@@ -390,9 +389,9 @@ sub set_options {
                 sort_order_list( $opt );
             }
             elsif ( $choice eq "show_view_count" ) {
-                my $prompt = 'Show view count in channel/playlist menu';
+                my $prompt = 'Show the view count in channel/playlist menus';
                 my $list = [
-                    'If sort-"view count"',
+                    'If sorted by "view count"',
                     'Always',
                 ];
                 _opt_choose_from_list_idx( $opt, $choice, $prompt, $list );
@@ -521,20 +520,16 @@ sub sort_order_list {
     my ( $opt ) = @_;
     my $backup_item  = $opt->{list_sort_item};
     my $backup_order = $opt->{list_sort_order};
-    my $sort_items = [
-        { key => 'upload_date',    prompt => 'Upload date' },
-        { key => 'title',          prompt => 'Title'       },
-        { key => 'view_count_raw', prompt => 'View count'  },
-        { key => 'duration',       prompt => 'Duration'    },
-    ];
+    my $sort_items = [ 'upload_date', 'title', 'view_count_raw', 'duration' ];
     my $confirm = '  CONFIRM';
     my @pre = ( undef, $confirm );
-    my $choices = [ @pre, map( "- $_->{prompt}", @$sort_items ) ];
-    my $tmp;
+    my $choices = [ @pre, map { s/_raw\z//; s/_/ /g; '- ' . ucfirst } @$sort_items ];
 
     while ( 1 ) {
-        my $first_index = first_index { $_->{key} eq $opt->{list_sort_item} } @$sort_items;
-        my $prompt = sprintf 'Sort item: [%s]', $sort_items->[$first_index]{prompt};
+        my $current = ucfirst $opt->{list_sort_item};
+        $current =~ s/_raw\z//;
+        $current =~ s/_/ /g;
+        my $prompt = sprintf 'Sort item: [%s]', $current;
         my $idx = choose (
             $choices,
             { prompt => $prompt, clear_screen => 0, layout => 3, index => 1, undef => '  BACK' }
@@ -548,12 +543,14 @@ sub sort_order_list {
             last;
         }
         $idx -= @pre;
-        $opt->{list_sort_item} = $sort_items->[$idx]{key};
-        $tmp                   = $sort_items->[$idx]{prompt};
+        $opt->{list_sort_item} = $sort_items->[$idx];
     }
 
     while ( 1 ) {
-        my $order_prompt = sprintf 'Sort order "%s": [%s]', $tmp, $opt->{list_sort_order};
+        my $curr_sort_item = ucfirst $opt->{list_sort_item};
+        $curr_sort_item =~ s/_raw\z//;
+        $curr_sort_item =~ s/_/ /g;
+        my $order_prompt = sprintf 'Sort order "%s": [%s]', $curr_sort_item, $opt->{list_sort_order};
         my $choice = choose (
             [ @pre, '- Asc', '- Desc' ],
             { prompt => $order_prompt, clear_screen => 0, layout => 3, undef => '  BACK' }
